@@ -159,7 +159,7 @@ typedef struct dec_server_record {
     Byte_t *jpipstream;           /**< JPT/JPP stream*/
     OPJ_SIZE_T jpipstreamlen;            /**< length of jpipstream*/
     msgqueue_param_t *msgqueue;   /**< parsed message queue of jpipstream*/
-    SOCKET listening_socket;      /**< listenning socket*/
+    SOCKET listening_socket;      /**< listening socket*/
 } dec_server_record_t;
 
 
